Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BOSHDeploymentExpansion ¶
type BOSHDeploymentExpansion interface{}
type BOSHDeploymentInterface ¶
type BOSHDeploymentInterface interface {
Create(*v1alpha1.BOSHDeployment) (*v1alpha1.BOSHDeployment, error)
Update(*v1alpha1.BOSHDeployment) (*v1alpha1.BOSHDeployment, error)
UpdateStatus(*v1alpha1.BOSHDeployment) (*v1alpha1.BOSHDeployment, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.BOSHDeployment, error)
List(opts v1.ListOptions) (*v1alpha1.BOSHDeploymentList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.BOSHDeployment, err error)
BOSHDeploymentExpansion
}
BOSHDeploymentInterface has methods to work with BOSHDeployment resources.
type BOSHDeploymentsGetter ¶
type BOSHDeploymentsGetter interface {
BOSHDeployments(namespace string) BOSHDeploymentInterface
}
BOSHDeploymentsGetter has a method to return a BOSHDeploymentInterface. A group's client should implement this interface.
type BoshdeploymentV1alpha1Client ¶
type BoshdeploymentV1alpha1Client struct {
// contains filtered or unexported fields
}
BoshdeploymentV1alpha1Client is used to interact with features provided by the boshdeployment group.
func New ¶
func New(c rest.Interface) *BoshdeploymentV1alpha1Client
New creates a new BoshdeploymentV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*BoshdeploymentV1alpha1Client, error)
NewForConfig creates a new BoshdeploymentV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *BoshdeploymentV1alpha1Client
NewForConfigOrDie creates a new BoshdeploymentV1alpha1Client for the given config and panics if there is an error in the config.
func (*BoshdeploymentV1alpha1Client) BOSHDeployments ¶
func (c *BoshdeploymentV1alpha1Client) BOSHDeployments(namespace string) BOSHDeploymentInterface
func (*BoshdeploymentV1alpha1Client) RESTClient ¶
func (c *BoshdeploymentV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type BoshdeploymentV1alpha1Interface ¶
type BoshdeploymentV1alpha1Interface interface {
RESTClient() rest.Interface
BOSHDeploymentsGetter
}
Source Files
¶
- boshdeployment.go
- boshdeployment_client.go
- doc.go
- generated_expansion.go