Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BOSHDeploymentLister ¶
type BOSHDeploymentLister interface {
// List lists all BOSHDeployments in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.BOSHDeployment, err error)
// BOSHDeployments returns an object that can list and get BOSHDeployments.
BOSHDeployments(namespace string) BOSHDeploymentNamespaceLister
BOSHDeploymentListerExpansion
}
BOSHDeploymentLister helps list BOSHDeployments.
func NewBOSHDeploymentLister ¶
func NewBOSHDeploymentLister(indexer cache.Indexer) BOSHDeploymentLister
NewBOSHDeploymentLister returns a new BOSHDeploymentLister.
type BOSHDeploymentListerExpansion ¶
type BOSHDeploymentListerExpansion interface{}
BOSHDeploymentListerExpansion allows custom methods to be added to BOSHDeploymentLister.
type BOSHDeploymentNamespaceLister ¶
type BOSHDeploymentNamespaceLister interface {
// List lists all BOSHDeployments in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.BOSHDeployment, err error)
// Get retrieves the BOSHDeployment from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.BOSHDeployment, error)
BOSHDeploymentNamespaceListerExpansion
}
BOSHDeploymentNamespaceLister helps list and get BOSHDeployments.
type BOSHDeploymentNamespaceListerExpansion ¶
type BOSHDeploymentNamespaceListerExpansion interface{}
BOSHDeploymentNamespaceListerExpansion allows custom methods to be added to BOSHDeploymentNamespaceLister.
Source Files
¶
- boshdeployment.go
- expansion_generated.go
Click to show internal directories.
Click to hide internal directories.